`xotl.tools.future.types`:mod: - Names for built-in types and extensions
========================================================================

.. module:: xotl.tools.future.types

This module complements the standard library's `types`:mod:.  This module
backports some things from later Pythons to earlier ones.

The following list is not complete:

.. class:: NoneType

   The type of ``None``.  In Python 3.10+, this is imported from `types`:mod:.
